@@ -23,9 +23,6 @@
 #include "windows.h"
 #include <stdio.h>
 
-#define g2_win32 0
-#define g2_wmf32 1
-
 extern HMENU hmenu;
 extern HANDLE ghModule;
 extern HINSTANCE g2res_DLL;
@@ -105,7 +102,7 @@ int g2_win32_FilledArc(int pid, void *pdp, int x, int y,
 		      int r1, int r2, double a1, double a2);
 int g2_win32_Ellipse(int pid, void *pdp, int x, int y, int r1, int r2);
 int g2_win32_FilledEllipse(int pid, void *pdp, int x, int y, int r1, int r2);
-int g2_win32_DrawString(int pid, void *pdp, int x, int y, char *text);
+int g2_win32_DrawString(int pid, void *pdp, int x, int y, const char *text);
 
 int g2_win32_AllocateBasicColors(int pid, void *pdp);
 
