@@ -82,7 +82,7 @@ int g2_open_X11X(int width, int height,
 	if(i==N_X11) {
 	    N_X11++;
 	    g2_X11_dev=g2_realloc(g2_X11_dev,
-			       sizeof(g2_X11_device)*N_X11);
+				  sizeof(g2_X11_device)*N_X11);
 	    xout=&g2_X11_dev[N_X11-1];
 	    pid=N_X11-1;
 	}
@@ -148,6 +148,7 @@ int g2_X11_init_X11X(int pid, int width, int height,
 	exit(-1);
     }
 
+
     xout->root=RootWindow(xout->display, DefaultScreen(xout->display));
     root=xout->root;
     
@@ -159,12 +160,12 @@ int g2_X11_init_X11X(int pid, int width, int height,
 			       CopyFromParent, InputOutput, CopyFromParent,
 			       CWEventMask,
 			       &wattr);
-    
-    xout->colormap=DefaultColormap(xout->display,
-				   DefaultScreen(xout->display));
 
     xout->gc=XCreateGC(xout->display, xout->window,
 		       0lu, NULL);
+
+    xout->colormap=DefaultColormap(xout->display,
+				   DefaultScreen(xout->display));
         
     XAllocNamedColor(xout->display, xout->colormap,
 		     "red", &r_scr, &r_exa);
@@ -172,6 +173,7 @@ int g2_X11_init_X11X(int pid, int width, int height,
 		     "white", &w_scr, &w_exa);
 
 
+    
     if(icon_data!=NULL) {
 	if(icon_width<=0 || icon_height<=0) {	  /* read icon from file */
 	    rv=XReadBitmapFile(xout->display, xout->window,
@@ -240,7 +242,7 @@ int g2_X11_init_X11X(int pid, int width, int height,
  
     XMapRaised(xout->display, xout->window);
     
-    XSetWindowBackground(xout->display, xout->window, w_scr.pixel);
+    //    XSetWindowBackground(xout->display, xout->window, w_scr.pixel);
     XClearWindow(xout->display,xout->window);
     
     g2_X11_paper(pid, NULL, 0);
@@ -258,8 +260,25 @@ int g2_X11_init_X11X(int pid, int width, int height,
 			    CWEventMask|CWBackingStore,
 			    &wattr);
 
-    if(XDoesBackingStore(XDefaultScreenOfDisplay(xout->display))!=Always)
-	fputs("g2: Warning! Backing store is not available.\n",stderr);
+    xout->dest = xout->window;
+
+    xout->backing_pixmap = None;
+
+    if(XDoesBackingStore(XDefaultScreenOfDisplay(xout->display))!=Always) {
+	/* fputs("g2: Warning! Backing store is not available.Allocating pixmap instead.\n", stderr); */
+	
+	xout->backing_pixmap = XCreatePixmap(xout->display, xout->window,
+					     xout->width, xout->height,
+					     DefaultDepth(xout->display, DefaultScreen(xout->display)));
+	XSetWindowBackgroundPixmap(xout->display, xout->window,
+				   xout->backing_pixmap);
+	  
+	XSetForeground (xout->display, xout->gc, w_scr.pixel);
+          
+	XFillRectangle(xout->display, xout->backing_pixmap, xout->gc,
+		       0, 0, xout->width, xout->height);
+	xout->dest = xout->backing_pixmap;
+    }
 
     XFlush(xout->display);
     return 0;
@@ -272,6 +291,8 @@ int g2_X11_delete(int pid, void *pdp)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
     XUnmapWindow(xout->display, xout->window);
+    if (xout->backing_pixmap != None)
+	XFreePixmap(xout->display,xout->backing_pixmap);
     XDestroyWindow(xout->display, xout->window);
     XDestroyWindow(xout->display, xout->root);
     XFreeGC(xout->display, xout->gc);
@@ -289,9 +310,19 @@ int g2_X11_delete(int pid, void *pdp)
 int g2_X11_clear(int pid, void *pdp)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-
-    XClearWindow(xout->display,xout->window);
-    XFlush(xout->display);
+    
+    if (xout->backing_pixmap == None)
+      {
+      XClearWindow(xout->display,xout->window);
+      }
+    else
+      {
+      XSetForeground (xout->display, xout->gc,
+                  xout->background);
+      XFillRectangle(xout->display, xout->dest, xout->gc,
+                 0, 0, xout->width, xout->height);
+      }
+    g2_X11_flush(pid,pdp);
     return 0;
 }
 
@@ -300,6 +331,10 @@ int g2_X11_clear(int pid, void *pdp)
 int g2_X11_flush(int pid, void *pdp)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
+    if( xout->backing_pixmap != None ) {
+      XCopyArea(xout->display, xout->dest, xout->window, xout->gc,
+              0, 0, xout->width, xout->height, 0, 0);
+      }
     XFlush(xout->display);
     return 0;
 }
@@ -356,9 +391,16 @@ int g2_X11_set_background(int pid, void *pdp, int color)
     g2_X11_device *xout=&g2_X11_dev[pid];
     if(color>=xout->NofInks || color<0)
 	return -1;
-    XSetWindowBackground(xout->display,xout->window,
+    if (xout->backing_pixmap == None)
+      {
+        XSetWindowBackground(xout->display,xout->dest,
 			 xout->inks[color]);
-    XClearWindow(xout->display,xout->window);
+      }
+    else
+      {
+	xout->background = xout->inks[color];
+      }
+    g2_X11_clear(pid,pdp);
     return 0;
 }
 
@@ -455,7 +497,7 @@ int g2_X11_set_font_size(int pid, void *pdp, int size)
 int g2_X11_plot(int pid, void *pdp, int x, int y)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawPoint(xout->display, xout->window, xout->gc,
+    XDrawPoint(xout->display, xout->dest, xout->gc,
 	       x, y);
     return 0;
 }
@@ -464,7 +506,7 @@ int g2_X11_plot(int pid, void *pdp, int x, int y)
 int g2_X11_line(int pid, void *pdp, int x1, int y1, int x2, int y2)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawLine(xout->display,xout->window,xout->gc,
+    XDrawLine(xout->display,xout->dest,xout->gc,
 	      x1, y1, x2, y2);
     return 0;
 }
@@ -480,7 +522,7 @@ int g2_X11_poly_line(int pid, void *pdp, int N, int *p)
 	points[i].x=(short)p[i*2];
 	points[i].y=(short)p[i*2+1];
     }
-    XDrawLines(xout->display,xout->window,xout->gc,
+    XDrawLines(xout->display,xout->dest,xout->gc,
 	       points, N,
 	       CoordModeOrigin);
     g2_free(points);
@@ -500,7 +542,7 @@ int g2_X11_polygon(int pid, void *pdp, int N, int *p)
     }
     points[N].x=(short)p[0];
     points[N].y=(short)p[1];
-    XDrawLines(xout->display,xout->window,xout->gc,
+    XDrawLines(xout->display,xout->dest,xout->gc,
 	       points, N+1,
 	       CoordModeOrigin);
     g2_free(points);
@@ -520,7 +562,7 @@ int g2_X11_filled_polygon(int pid, void *pdp, int N, int *p)
     }
     points[N].x=(short)p[0];
     points[N].y=(short)p[1];
-    XFillPolygon(xout->display,xout->window,xout->gc,
+    XFillPolygon(xout->display,xout->dest,xout->gc,
 		 points, N+1,
 		 Complex, CoordModeOrigin);
     g2_free(points);
@@ -539,7 +581,7 @@ int g2_X11_triangle(int pid, void *pdp,
     points[1].x=x2; points[1].y=y2; 
     points[2].x=x3; points[2].y=y3; 
     points[3].x=x1; points[3].y=y1; 
-    XDrawLines(xout->display,xout->window,xout->gc,
+    XDrawLines(xout->display,xout->dest,xout->gc,
 	       points, 4, CoordModeOrigin);
     return 0;
 }
@@ -556,7 +598,7 @@ int g2_X11_filled_triangle(int pid, void *pdp,
     points[1].x=x2; points[1].y=y2; 
     points[2].x=x3; points[2].y=y3; 
     points[3].x=x1; points[3].y=y1; 
-    XFillPolygon(xout->display,xout->window,xout->gc,
+    XFillPolygon(xout->display,xout->dest,xout->gc,
 		 points, 4, Convex, CoordModeOrigin);
     return 0;
 }
@@ -565,7 +607,7 @@ int g2_X11_filled_triangle(int pid, void *pdp,
 int g2_X11_rectangle(int pid, void *pdp, int x1, int y1, int x2, int y2)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawRectangle(xout->display,xout->window,xout->gc,
+    XDrawRectangle(xout->display,xout->dest,xout->gc,
 		   x1, y1, x2-x1, y2-y1);
     return 0;
 }
@@ -575,9 +617,9 @@ int g2_X11_rectangle(int pid, void *pdp, int x1, int y1, int x2, int y2)
 int g2_X11_filled_rectangle(int pid, void *pdp, int x1, int y1, int x2, int y2)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawRectangle(xout->display,xout->window,xout->gc,
+    XDrawRectangle(xout->display,xout->dest,xout->gc,
 		   x1, y1, x2-x1, y2-y1);
-    XFillRectangle(xout->display,xout->window,xout->gc,
+    XFillRectangle(xout->display,xout->dest,xout->gc,
 		   x1, y1, x2-x1, y2-y1);
     return 0;
 }
@@ -591,7 +633,7 @@ int g2_X11_arc(int pid, void *pdp, int x, int y,
     a2=fmod(a2, 360.);
     if(a2-a1<0)
 	a2+=360.;
-    XDrawArc(xout->display,xout->window,xout->gc,
+    XDrawArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     (int)(a1*64.), (int)((a2-a1)*64.));
@@ -607,11 +649,11 @@ int g2_X11_filled_arc(int pid, void *pdp, int x, int y,
     a2=fmod(a2, 360.);
     if(a2-a1<0)
 	a2+=360.;
-    XDrawArc(xout->display,xout->window,xout->gc,
+    XDrawArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     a1*64, (a2-a1)*64.0);
-    XFillArc(xout->display,xout->window,xout->gc,
+    XFillArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     (int)(a1*64.), (int)((a2-a1)*64.));
@@ -622,7 +664,7 @@ int g2_X11_filled_arc(int pid, void *pdp, int x, int y,
 int g2_X11_ellipse(int pid, void *pdp, int x, int y, int r1, int r2)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawArc(xout->display,xout->window,xout->gc,
+    XDrawArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     0,360*64);
@@ -633,11 +675,11 @@ int g2_X11_ellipse(int pid, void *pdp, int x, int y, int r1, int r2)
 int g2_X11_filled_ellipse(int pid, void *pdp, int x, int y, int r1, int r2)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawArc(xout->display,xout->window,xout->gc,
+    XDrawArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     0,360*64);
-    XFillArc(xout->display,xout->window,xout->gc,
+    XFillArc(xout->display,xout->dest,xout->gc,
 	     x-r1, y-r2,
 	     r1*2, r2*2,
 	     0,360*64);
@@ -646,10 +688,10 @@ int g2_X11_filled_ellipse(int pid, void *pdp, int x, int y, int r1, int r2)
 }
  
 
-int g2_X11_draw_string(int pid, void *pdp, int x, int y, char *text)
+int g2_X11_draw_string(int pid, void *pdp, int x, int y, const char *text)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
-    XDrawString(xout->display,xout->window,xout->gc,
+    XDrawString(xout->display,xout->dest,xout->gc,
 		x, y, text, strlen(text));
     return 0;
 }
@@ -669,7 +711,6 @@ int g2_X11_image(int pid, void *pdp,
 	ink_array[i]=xout->inks[pen_array[i]];
 
     screen=DefaultScreenOfDisplay(xout->display);
-    printf("BP1\n");
     image=XCreateImage(xout->display,
 		       DefaultVisualOfScreen(screen),
 		       DefaultDepthOfScreen(screen),
@@ -677,16 +718,13 @@ int g2_X11_image(int pid, void *pdp,
 		       0,			  /* offset */
 		       (char *)ink_array,
 		       width, height,
-		       sizeof(unsigned long)*8,		  /* bitmap pad */
+		       sizeof(unsigned long)*8,	  /* bitmap pad */
 		       0);			  /* bytes per line */
-    printf("BP2\n");
     /* XInitImage(image); problems with AIX ?!! */
-    printf("BP3 image=%p\n", (void*)image);
-    XPutImage(xout->display, xout->window, xout->gc,
+    XPutImage(xout->display, xout->dest, xout->gc,
 	      image,
 	      0, 0,
 	      x, y, width, height);
-    printf("BP4\n");
 	
     XDestroyImage(image);
     free(ink_array);
